# <img alt="matminer" src="docs_rst/_static/matminer_logo_small.png" width="300">

matminer is a library for performing data mining in the field of materials science.

- **Website (including documentation):** https://hackingmaterials.github.io/matminer/
- **Help/Support:** https://groups.google.com/forum/#!forum/matminer
- **Source:** https://github.com/hackingmaterials/matminer
